@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Optional
 
-__all__ = ["GeneratorError", "ParseError", "PropertyError"]
+__all__ = ["GeneratorError", "ParseError", "PropertyError", "ValidationError"]
 
 from pydantic import BaseModel
 
@@ -37,3 +37,7 @@ class PropertyError(ParseError):
     """ Error raised when there's a problem creating a Property """
 
     header = "Problem creating a Property: "
+
+
+class ValidationError(Exception):
+    pass
